package com.ascendfinalproject.warehouse.kafkaservice;

import com.ascendfinalproject.warehouse.models.WarehouseOrderRequest;
import com.ascendfinalproject.warehouse.models.WarehouseOrderResponse;
import lombok.extern.slf4j.Slf4j;
import org.apache.kafka.clients.producer.ProducerRecord;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import reactor.core.publisher.Flux;
import reactor.core.publisher.Mono;
import reactor.kafka.sender.KafkaSender;
import reactor.kafka.sender.SenderRecord;
import reactor.kafka.sender.SenderResult;

@Service
@Slf4j
public class Sender {

  @Autowired
  private KafkaSender<String, WarehouseOrderRequest> kafkaOMSProducer;

  @Autowired
  private KafkaSender<String, WarehouseOrderResponse> kafkaUpdateEventProducer;


  private static final String TOPIC = "WMOS_ORDER_UPDATE";

  private static final String OMS = "OMS_ORDER_UPDATE";

//  public void sendOrder(WarehouseOrderRequest currentOrder) {
//    ProducerRecord<String, WarehouseOrderRequest> record = new ProducerRecord<>(TOPIC, currentOrder);
//    Flux<SenderResult<WarehouseOrderRequest>> sendToKafka = kafkaOMSProducer.send(Mono.just(SenderRecord.create(record, currentOrder)))
//            .doOnError(throwable -> System.out.println(throwable))
//            .doOnNext(t -> {
//              if (null != t.exception()) {
//                System.out.println("it works!");
//              }
//            });
//    sendToKafka.doOnError(throwable -> log.error("error")).subscribe();
//  }

  public void sendUpdatedOrder(WarehouseOrderResponse currentOrder) {
    ProducerRecord<String, WarehouseOrderResponse> record = new ProducerRecord<>(TOPIC, currentOrder);
    Flux<SenderResult<WarehouseOrderResponse>> sendToKafka = kafkaUpdateEventProducer.send(Mono.just(SenderRecord.create(record, currentOrder)))
            .doOnError(throwable -> System.out.println(throwable))
            .doOnNext(t -> {
              if (null != t.exception()) {
                System.out.println("it works!");
              }
            });
    sendToKafka.doOnError(throwable -> log.error("error")).subscribe();
  }
}
